Transport

Enum Transport 

#[repr(u8)]
pub enum Transport { Local = 0, Tcp = 1, Udp = 2, }
Transport protocol to use for delivering messages sent to an ActorPath

Note

Dispatcher implementations are not required to implement all protocols. Check your concrete implementation, before selecting an arbitrary protocol.

Variants



Local = 0

Local reflection only, no network messages involved



Tcp = 1

Send messages over TCP



Udp = 2

Send messages as UDP datagrams

Implementations

Source

impl Transport

pub fn is_local(&self) -> bool

Returns true if this is an instance of Transport::Local

pub fn is_remote(&self) -> bool

Returns true if this is not an instance of Transport::Local