DynActorRef

Struct DynActorRef 

pub struct DynActorRef { /* private fields */ }
A kind of actor reference that only allows network messages to be sent

For local-only dynamically typed actors, consider using type Message = Box<Any>; together with ActorRef<Box<Any>> instead.

Implementations

Source

impl DynActorRef

pub fn enqueue(&self, msg: NetMessage)

Enqueue a preconstructed NetMessage directly into the dynamic mailbox.

pub fn can_upgrade_component(&self) -> bool

Attempts to upgrade the contained component, returning true if possible.

This a somewhat weaker equivalent to an is_alive function, in that it doesn’t check the lifecycle status of the target component.

pub fn tell<I>(&self, v: I)
where I: Into<NetMessage>,

Send a network message to the target actor