NamedPath

Struct NamedPath 

pub struct NamedPath { /* private fields */ }
A named actor path identifies a service, rather than a concrete actor instance

Named paths must be registered to a particular actor, and their registration can be changed over time, as actors fail and are replaced, for example.

Named paths may be described hierarchically, similar to URLs.

A named path may look something like "tcp://127.0.0.1:8080/my-actor-group/my-actor", for example.

Implementations

Source

impl NamedPath

pub fn new( protocol: Transport, address: IpAddr, port: u16, path: Vec<String>, ) -> NamedPath

Construct a new named path from parts

Make sure that none of the elements of the path vector contain slashes (i.e., /), as those will be the path separators for the individual elements later.

pub fn with_socket( protocol: Transport, socket: SocketAddr, path: Vec<String>, ) -> NamedPath

Construct a new named path from a socket and vector of path elements

Make sure that none of the elements of the path vector contain slashes (i.e., /), as those will be the path separators for the individual elements later.

pub fn with_system(system: SystemPath, path: Vec<String>) -> NamedPath

Construct a new named path from a system path and vector of path elements

Make sure that none of the elements of the path vector contain slashes (i.e., /), as those will be the path separators for the individual elements later.

pub fn path_ref(&self) -> &[String]

Returns a reference to the path vector

pub fn clone_path(&self) -> Vec<String>

Returns a copy to the path vector

pub fn into_path(self) -> Vec<String>

Return just the path vector, discarding the SystemPath

pub fn system_mut(&mut self) -> &mut SystemPath

Returns a mutable reference to this path’s system path part

pub fn push(&mut self, segment: String) -> Result<(), PathParseError>

Add the given segment to the path, if it is valid to do so

pub fn append(self, path: &str) -> Result<NamedPath, PathParseError>

Add the given relative path to this path, if it is valid to do so