Module component

Module component 

Traits and structs for component API and internals

Structs

BlockingFuture
A future that is supposed to be blocking the component’s execution until completed
Component
A concrete component instance
ComponentContext
The contextual object for a Kompact component
ComponentCore
The core of a Kompact component
ComponentDefinitionAccess
Gives access to the component definition within a future/async function
ComponentFault
A component-local fault produced by a handler.
ContextSystemHandle
The SystemHandle provided by a ComponentContext
ExecuteResult
Statistics about the last invocation of execute.
LockPoisoned
Error for when the component definition lock has been poisoned
NonBlockingFuture
A future that is supposed to be polled while the component is running normally

Enums

Handled
State transition indication at the end of a message or event handler.
HandlerError
An abnormal result returned from a component handler.
SchedulingDecision
Indicates whether or not a component should be sent to the Scheduler

Traits

AbstractComponent
An object-safe trait that exposes most of functionality of a Component that isn’t dependent on a particular ComponentDefinition.
ComponentDefinition
The core trait every component must implement
ComponentLifecycle
A trait to customise handling of lifecycle events
ComponentLogging
An abstraction over providers of Kompact loggers
ComponentTraits
A trait bound alias for the trait required by the generic parameter of a Component
CoreContainer
A trait for abstracting over structures that contain a component core
DynamicComponentDefinition
Object-safe part of ComponentDefinition.
DynamicPortAccess
A mechanism for dynamically getting references to provided/required ports from a component.
HandlerResultExt
Extension helpers for classifying fallible results in component handlers.
LockingProvideRef
Same as ProvideRef, but for instances that must be locked first
LockingRequireRef
Same as RequireRef, but for instances that must be locked first
MsgQueueContainer
Anything with this trait can be turned into an ActorRef as long as its behind an Arc or Weak
Provide
A trait implementing handling of provided events of P
ProvideRef
A convenience abstraction over concrete port instance fields
Require
A trait implementing handling of required events of P
RequireRef
A convenience abstraction over concrete port instance fields
UniqueRegistrable
A trait for component views that can be used for unique actor registration

Functions

default_recovery_function
Kompact’s default fault recovery policy is to simply ignore the fault

Type Aliases

BoxedHandlerError
A boxed error returned from a Kompact handler.
DynamicComponentDefinitionMutexGuard
Mutex guard guarding a DynamicComponentDefinition trait object.
HandlerResult
The result returned from component handlers.