ConfigPathError

Enum ConfigPathError 

pub enum ConfigPathError {
    InvalidPath {
        path: String,
    },
    MissingKey {
        path: String,
    },
    MissingIndex {
        path: String,
    },
    InvalidKeyAccess {
        path: String,
        key: String,
        value_type: &'static str,
    },
    InvalidIndexAccess {
        path: String,
        index: usize,
        value_type: &'static str,
    },
}
Errors raised while traversing a parsed configuration value.

Variants



InvalidPath

The requested path string is malformed.

Fields

path: String

The malformed config path.



MissingKey

The requested key was missing.

Fields

path: String

The full missing config path.



MissingIndex

The requested array element was missing.

Fields

path: String

The full missing config path.



InvalidKeyAccess

A key access was attempted on a non-table value.

Fields

path: String

The full config path that was being traversed.

key: String

The key fragment whose access failed.

value_type: &'static str

The type of the parent value that rejected the key access.



InvalidIndexAccess

An index access was attempted on a non-array value.

Fields

path: String

The full config path that was being traversed.

index: usize

The index fragment whose access failed.

value_type: &'static str

The type of the parent value that rejected the index access.

Implementations

Source

impl ConfigPathError

pub fn is_missing(&self) -> bool

Returns true if the error denotes a missing path element.