install_manual_timer

Function install_manual_timer 

pub fn install_manual_timer(
    config: &mut KompactConfig,
) -> ManualTimer<Uuid, ActorRefState, ActorRefState>
Replaces the default threaded timer with a manually-driven timer and returns the control handle for tests.

The returned timer can be advanced deterministically with timer::ManualTimer::advance_by or timer::ManualTimer::advance_to_next.