NetworkDispatcher

Struct NetworkDispatcher 

pub struct NetworkDispatcher { /* private fields */ }
A network-capable dispatcher for sending messages to remote actors

Construct this using NetworkConfig.

This dispatcher automatically creates channels to requested target systems on demand and maintains them while in use.

The current implementation only supports TCP as a transport protocol.

If possible, this implementation will “reflect” messages to local actors directly back up, instead of serialising them first.

Implementations

Source

impl NetworkDispatcher

pub fn new(notify_ready: KPromise<()>) -> Self

Create a new dispatcher with the default configuration

See also NetworkConfig.

Example

This example binds to local host on a free port chosen by the operating system.

use kompact::prelude::*;
use kompact_net::NetworkDispatcher;

let mut conf = KompactConfig::default();
conf.system_components(DeadletterBox::new, NetworkDispatcher::new);
let system = conf.build().wait().expect("system");
pub fn with_config(cfg: NetworkConfig, notify_ready: KPromise<()>) -> Self

Create a new dispatcher with the given configuration

For better readability in combination with system_components, use NetworkConfig::build instead.

pub fn system_path_ref(&mut self) -> &SystemPath

Return a reference to the cached system path

Mutable, since it will update the cached value, if necessary.

Source

impl NetworkDispatcher

pub fn network_status_port(&mut self) -> &mut ProvidedPort<NetworkStatusPort>

Returns the provided network status port for this dispatcher.