pub enum NetworkStatusRequest {
DisconnectSystem(SystemPath),
ConnectSystem(SystemPath),
BlockSystem(SystemPath),
BlockIp(IpAddr),
BlockIpNet(IpNet),
AllowSystem(SystemPath),
AllowIp(IpAddr),
AllowIpNet(IpNet),
}Expand description
Requests for transport-specific network status operations.
Variants
DisconnectSystem(SystemPath)
Request that the connection to the given system is gracefully closed.
ConnectSystem(SystemPath)
Request that a connection is established to the given system.
BlockSystem(SystemPath)
Request that a system path be blocked.
BlockIp(IpAddr)
Request that an IP address be blocked.
BlockIpNet(IpNet)
Request that an IP network be blocked.
AllowSystem(SystemPath)
Request that a previously blocked system be allowed again.
AllowIp(IpAddr)
Request that a previously blocked IP address be allowed again.
AllowIpNet(IpNet)
Request that a previously blocked IP network be allowed again.