pub enum PathResolvable {
Path(ActorPath),
ActorId(Uuid),
Alias(String),
Segments(Vec<String>),
System,
}Expand description
Something that can resolved to some kind of path by the dispatcher
Variants
Path(ActorPath)
An actual actor path
ActorId(Uuid)
The unique id of an actor
Can be resolved to a unique path in the current system.
Alias(String)
An actor path alias with all segments merged
Can be resolved to a named path in the current system.
Segments(Vec<String>)
An actor path alias with all segments individually
Can be resolved to a named path in the current system.
System
The system path (as provided by the dispatcher)