pub enum TryDualLockError {
LeftWouldBlock,
RightWouldBlock,
LeftPoisoned,
RightPoisoned,
}Expand description
This error type is returned when on on_dual_definition fails,
indicating that a proper lock could not be established on both components.
Variants
LeftWouldBlock
Indicates that the first component would block while waiting to be locked.
RightWouldBlock
Indicates that the second component would block while waiting to be locked.
LeftPoisoned
Indicates that the first component has had its mutex poisoned.
RightPoisoned
Indicates that the second component has had its mutex poisoned.