pub enum UnpackError<T> {
NoIdMatch(T),
NoCast(Box<dyn Any + Send>),
DeserError(SerError),
}Expand description
An error that is thrown when deserialisation of a NetMessage is attempted.
Variants
NoIdMatch(T)
ser_id did not match the given Deserialiser.
NoCast(Box<dyn Any + Send>)
Box<dyn Any>::downcast() failed.
DeserError(SerError)
An error occurred during deserialisation of the buffer.
This can not contain T, as the buffer may have been corrupted during the failed attempt.
Implementations