info_lifecycle

Macro info_lifecycle 

macro_rules! info_lifecycle {
    ($component:ty) => { ... };
}
A macro that provides an implementation of ComponentLifecycle for the given component that logs the lifecycle stages at INFO log level.

Use this in components that do not require any special treatment of lifecycle events besides logging.

Example

To log lifecycle events for a component TestComponent, write: info_lifecycle!(TestComponent);