pub enum DispatchData {
Lazy(Box<dyn Serialisable>, ActorPath, ActorPath),
Serialised(SerialisedFrame),
NetMessage(NetMessage),
}Expand description
An abstraction over lazy or eagerly serialised data sent to the dispatcher
Variants
Lazy(Box<dyn Serialisable>, ActorPath, ActorPath)
Lazily serialised variant – must still be serialised by the dispatcher or networking system (Serialisable Msg, Source, Destination)
Serialised(SerialisedFrame)
Should be serialised and framed.
NetMessage(NetMessage)
Used in message forwarding
Implementations
Sourceimpl DispatchData
impl DispatchData
Sourcepub fn into_local(self) -> Result<NetMessage, SerError>
pub fn into_local(self) -> Result<NetMessage, SerError>
Try to extract a network message from this data for local delivery
This can fail, if the data can’t be moved onto the heap, and serialisation also fails.
Sourcepub fn into_serialised(
self,
buf: &mut BufferEncoder<'_>,
) -> Result<SerialisedFrame, SerError>
pub fn into_serialised( self, buf: &mut BufferEncoder<'_>, ) -> Result<SerialisedFrame, SerError>
Try to serialise this to data to bytes for remote delivery