pub enum RegistrationError {
DuplicateEntry,
Unsupported,
InvalidPath(PathParseError),
}Expand description
An error that can occur during actor path registration
Variants
DuplicateEntry
An actor path with the same name exists already
Unsupported
This kind of registration is unsupported by the system’s dispatcher implementation
InvalidPath(PathParseError)
The supplied path was not invalid