UnpackError

Enum UnpackError 

pub enum UnpackError<T> {
    NoIdMatch(T),
    NoCast(Box<dyn Any + Send>),
    DeserError(SerError),
}
An error that is thrown when deserialisation of a NetMessage is attempted.

Variants



NoIdMatch(T)

ser_id did not match the given Deserialiser.



NoCast(Box<dyn Any + Send>)

Box<dyn Any>::downcast() failed.



DeserError(SerError)

An error occurred during deserialisation of the buffer.

This can not contain T, as the buffer may have been corrupted during the failed attempt.

Implementations

Source

impl<T> UnpackError<T>

pub fn get(self) -> Option<T>

Retrieve the wrapped T instance, if any

pub fn get_box(self) -> Option<Box<dyn Any + Send>>

Retrieve a wrapped any box, if there is any