DeserialisedMessage

Struct DeserialisedMessage 

pub struct DeserialisedMessage<T> {
    pub sender: ActorPath,
    pub receiver: ActorPath,
    pub content: T,
}
A deserialised variant of NetMessage

Can be obtained via the try_into_deserialised function.

Fields

sender: ActorPath

The sender of the message

More concretely, this is the actor path that was supplied as a source by the original sender.

receiver: ActorPath

The receiver of the message

More concretely, this is the actor path that was used as a destination for the message. In particular, of the message was sent to a named path for the current component, instead of the unique path, then this will be the named path.

content: T

The actual deserialised content of the message

Implementations

Source

impl<T> DeserialisedMessage<T>

pub fn with( sender: ActorPath, receiver: ActorPath, content: T, ) -> DeserialisedMessage<T>

Create a new deserialised message