Serialised

Struct Serialised 

pub struct Serialised {
    pub ser_id: u64,
    pub data: Bytes,
}
Wrapper for serialised data with a serialisation id

The serialisastion id identifies the Serialiser used to serialise the data, and should be used to match the corresponding Deserialiser as well.

Fields

ser_id: u64

The serialisation id of the serialiser used to serialise the data

data: Bytes

The serialised bytes