BufferChunk

Struct BufferChunk 

pub struct BufferChunk { /* private fields */ }
BufferChunk is a lockable pinned byte-slice All modifications to the Chunk goes through the get_slice method

Implementations

Source

impl BufferChunk

pub fn new(size: usize) -> BufferChunk

Allocate a new Default BufferChunk

pub fn from_chunk( raw_chunk: *mut dyn Chunk, allocator: Arc<dyn ChunkAllocator>, ) -> BufferChunk

Creates a BufferChunk using the given Chunk

pub fn len(&self) -> usize

Get the length of the BufferChunk

pub fn is_empty(&self) -> bool

pub fn swap_buffer(&mut self, other: &mut BufferChunk)

Swaps self with other in-place

pub fn get_lease(&mut self, from: usize, to: usize) -> ChunkLease

Returns a ChunkLease pointing to the subslice between from and toof the BufferChunk the returned lease is a consumable Buf.

pub fn get_lock(&self) -> Arc<()>

Clones the lock, the BufferChunk will be locked until all given locks are deallocated

pub fn free(&mut self) -> bool

Returns true if this BufferChunk is available again

pub fn lock(&mut self)

Locks the BufferChunk, it will not be writable nor will any leases be created before it has been unlocked.