Module network_thread

Module network_thread 

Structs

BlockList
NetworkThread
Thread structure responsible for driving the Network IO
NetworkThreadBuilder
Builder struct, can be sent to a thread safely to launch a NetworkThread

Constants

MAX_INTERRUPTS
How many times to retry on interrupt before we give up