NetworkStatusCounter

Struct NetworkStatusCounter 

pub struct NetworkStatusCounter {
    pub network_status_port: RequiredPort<NetworkStatusPort>,
    pub connection_established: u32,
    pub connection_lost: u32,
    pub connection_dropped: u32,
    pub connection_closed: u32,
    pub connected_systems: Vec<(SystemPath, SessionId)>,
    pub disconnected_systems: Vec<(SystemPath, SessionId)>,
    pub soft_connection_limit_exceeded: u32,
    pub hard_connection_limit_reached: u32,
    pub network_out_of_buffers: u32,
    pub critical_network_failure: u32,
    /* private fields */
}
Actor which can subscribe to the NetworkStatusPort and maintains a counter of how many of each kind of NetworkStatusUpdate has been received.

Fields

network_status_port: RequiredPort<NetworkStatusPort>

The NetworkStatusPort, needs to be exposed to allow connecting to it

connection_established: u32

Counts the number of connection_established messages received

connection_lost: u32

Counts the number of connection_lost messages received

connection_dropped: u32

Counts the number of connection_dropped messages received

connection_closed: u32

Counts the number of connection_closed messages received

connected_systems: Vec<(SystemPath, SessionId)>

Contains all SystemPath’s received in a ConnectionEstablished

disconnected_systems: Vec<(SystemPath, SessionId)>

Contains all SystemPath’s received in a ConnectionLost or ConnectionClosed message

soft_connection_limit_exceeded: u32

Counts the number of SoftConnectionLimitExceeded messages received

hard_connection_limit_reached: u32

Counts the number of HardConnectionLimitReached messages received

network_out_of_buffers: u32

Counts the number of network_out_of_buffers messages received

critical_network_failure: u32

Counts the number of CriticalNetworkFailure messages received

Implementations

Source

impl NetworkStatusCounter

pub fn new() -> NetworkStatusCounter

Creates a new uninitialised NetworkStatusCounter with all counters set to 0

pub fn set_status_sender(&mut self, sender: Sender<NetworkStatus>)

Sets a sender which the NetworkStatusCounter will foward all the NetworkStatus events to

pub fn send_status_request(&mut self, request: NetworkStatusRequest)

triggers the given request on the NetworkStatusPort

pub fn started_future(&mut self) -> KFuture<()>

Creates a future that will be fulfilled when the component starts

pub fn corrupt_network(&mut self) -> Result<(), SerError>

Creates a faulty Message which will cause the local NetworkThread to panic when it tries to send it to the remote host.

Fails to corrupt the network if there are no connected systems to use as receiver for the corrupt message and returns an error instead.