SerErrorKind

Enum SerErrorKind 

pub enum SerErrorKind {
    InvalidData,
    InvalidType,
    Buffer,
    NoBuffersAvailable,
    NoClone,
    ThirdParty,
    Unknown,
}
Stable categories for serialisation and deserialisation failures.

Variants



InvalidData

The data was invalid, corrupted, or otherwise not as expected.



InvalidType

The data represents the wrong type, or an unknown type.



Buffer

The buffer used for serialisation failed.



NoBuffersAvailable

No buffer was available.

Raised by actors attempting to send more messages than their buffers allow or what the network is able to handle.



NoClone

The type can not be cloned.



ThirdParty

An error forwarded from a third-party crate.



Unknown

Any other kind of serialisation error.