pub struct DynActorRef { /* private fields */ }Expand description
A kind of actor reference that only allows network messages to be sent
For local-only dynamically typed actors, consider using type Message = Box<Any>;
together with ActorRef<Box<Any>> instead.
Implementations
Sourceimpl DynActorRef
impl DynActorRef
Sourcepub fn enqueue(&self, msg: NetMessage)
pub fn enqueue(&self, msg: NetMessage)
Enqueue a preconstructed NetMessage directly into the dynamic mailbox.
Sourcepub fn can_upgrade_component(&self) -> bool
pub fn can_upgrade_component(&self) -> bool
Attempts to upgrade the contained component, returning true if possible.
This a somewhat weaker equivalent to an is_alive function, in that
it doesn’t check the lifecycle status of the target component.
Sourcepub fn tell<I>(&self, v: I)where
I: Into<NetMessage>,
pub fn tell<I>(&self, v: I)where
I: Into<NetMessage>,
Send a network message to the target actor