FaultContext

Struct FaultContext 

pub struct FaultContext {
    pub component_id: Uuid,
    pub fault: Fault,
}
Information about the fault that occurred

Fields

component_id: Uuid

The id of the component that faulted

fault: Fault

The concrete fault.

Implementations

Source

impl FaultContext

pub fn recover_with<F>(self, f: F) -> RecoveryHandler

Produce a Recoverhandler with f describing the actions to take in order to recover from this fault

The action described by this object will be executed on the Supervisor. This means you cannot block on the result of any notify futures, without deadlocking your system!

If you need to perform a complicated setup sequence, consider starting a temporary component to drive the futures involved, instead of handling everything in the recovery handler.

pub fn ignore(self) -> RecoveryHandler

Simply ignore the fault and don’t recover at all

pub fn restart_default<C>(self) -> RecoveryHandler

Create and start the Default instance of C