pub struct ScheduledTimer(/* private fields */);Expand description
Opaque reference to a scheduled instance of a timer
Use this to cancel the timer with cancel_timer.
Instances are returned from functions that schedule timers, such as schedule_once and schedule_periodic.
Implementations
Sourceimpl ScheduledTimer
impl ScheduledTimer
Sourcepub fn from_uuid(id: Uuid) -> ScheduledTimer
pub fn from_uuid(id: Uuid) -> ScheduledTimer
Create a ScheduledTimer from a Uuid handle