pub struct SystemPath { /* private fields */ }Expand description
The part of an ActorPath that refers to the KompactSystem
As a URI, a SystemPath looks like "tcp://127.0.0.1:8080", for example.
Implementations
Sourceimpl SystemPath
impl SystemPath
Sourcepub fn new(protocol: Transport, address: IpAddr, port: u16) -> SystemPath
pub fn new(protocol: Transport, address: IpAddr, port: u16) -> SystemPath
Construct a new system path from individual parts
Sourcepub fn with_socket(protocol: Transport, socket: SocketAddr) -> SystemPath
pub fn with_socket(protocol: Transport, socket: SocketAddr) -> SystemPath
Construct a new system path from individual parts using a SocketAddr
Sourcepub fn protocol(&self) -> Transport
pub fn protocol(&self) -> Transport
Returns a reference to the Transport protocol associated with with this system path
Sourcepub fn address(&self) -> &IpAddr
pub fn address(&self) -> &IpAddr
Returns a reference to the IP address associated with with this system path
Sourcepub fn into_named_with_string(
self,
path: &str,
) -> Result<NamedPath, PathParseError>
pub fn into_named_with_string( self, path: &str, ) -> Result<NamedPath, PathParseError>
Create a named path starting with this system path and ending with the given string
Paths created with this function will be validated to be a valid lookup path, and an error will be returned if they are not.
Sourcepub fn socket_address(&self) -> SocketAddr
pub fn socket_address(&self) -> SocketAddr
Returns the SocketAddr corresponding to the SystemPath
Sourcepub fn into_named_with_vec(
self,
path: Vec<String>,
) -> Result<NamedPath, PathParseError>
pub fn into_named_with_vec( self, path: Vec<String>, ) -> Result<NamedPath, PathParseError>
Create a named path starting with this system path and ending with the sequence of path segments
Paths created with this function will be validated to be a valid lookup path, and an error will be returned if they are not.
Sourcepub fn into_unique(self, id: Uuid) -> UniquePath
pub fn into_unique(self, id: Uuid) -> UniquePath
Create a unique path starting with this system path and ending with the given id