WithSender

Struct WithSender 

pub struct WithSender<Req, Resp>
where Req: MessageBounds, Resp: MessageBounds,
{ /* private fields */ }
A generic type for request-response messages

This type contains information about the target actor for the response, as well as the actual request itself.

Implementations can also be dereferenced to the request message and replied to with a response.

Implementations

Source

impl<Req, Resp> WithSender<Req, Resp>
where Req: MessageBounds, Resp: MessageBounds,

pub fn new(content: Req, sender: ActorRef<Resp>) -> WithSender<Req, Resp>

Create a new instance from a request and an actor to reply to

pub fn from( content: Req, sender: &dyn ActorRefFactory<Message = Resp>, ) -> WithSender<Req, Resp>

Create a new instance from a request and something that can produce a reference to an actor to reply to

This variant is convenient from within a component, as components and their contexts implement ActorRefFactory for their actor message type.

pub fn sender(&self) -> &ActorRef<Resp>

Returns a reference to the response target actor

pub fn content(&self) -> &Req

Returns a reference to the content

pub fn take_content(self) -> Req

Takes only the content

This prevents the request from being completed, as the sender is dropped! Use only after replying to the request.