Module runtime

Module runtime 

Kompact system runtime facilities, such as configuration and schedulers

Modules

keys
Configuration keys for Kompact systems.

Structs

ExecutorScheduler
A wrapper for schedulers from the executors crate
KompactConfig
A configuration builder for Kompact systems
KompactSystem
A Kompact system is a collection of components and services
SchedulerShutdownError
Error returned when a scheduler fails to shut down.
ShutdownError
Error returned when a Kompact system fails to shut down.
SystemComponentsShutdownError
Error returned when system components fail to shut down.
TimerShutdownError
Error returned when a timer fails to shut down.

Enums

KompactError
A Kompact system error

Constants

MINIMAL_CONFIG
A minimal Kompact configuration

Traits

DistributedSystemHandle
Distributed-only extensions for a SystemHandle.
Scheduler
API for a Kompact scheduler
SystemComponents
A trait to provide custom implementations of all system components
SystemHandle
A limited version of a KompactSystem
TimerComponent
Extra trait for timers to implement

Functions

drop_default_logger
Removes the global default logger