DeadletterBox

Struct DeadletterBox 

pub struct DeadletterBox { /* private fields */ }
The default deadletter box

Simply logs every received message at the info level and then discards it.

Implementations

Source

impl DeadletterBox

pub fn new(notify_ready: KPromise<()>) -> DeadletterBox

Creates a new deadletter box

The notify_ready promise will be fulfilled, when the component received a Start event.