pub struct DispatchingPath<'a, 'b> { /* private fields */ }Expand description
A temporary combination of an ActorPath and something that can dispatch stuff.
This can be used when you want to use a different actor path than the one of the current component for a tell but still need to use the component’s dispatcher for the message. This is useful for forwarding components, for example, when trying to preserve the original sender.
See also using_dispatcher.