ExecuteResult

Struct ExecuteResult 

pub struct ExecuteResult { /* private fields */ }
Statistics about the last invocation of execute.

Implementations

Source

impl ExecuteResult

pub fn new(blocking: bool, count: usize, skip: usize) -> ExecuteResult

Create a new execute result

count gives the total number of events handled during the invocation skip gives the offset from where queues will be checked during the next invocation (used for fairness)

pub fn shutdown(count: usize, skip: usize) -> ExecuteResult

Create an execute result indicating a normal shutdown request.

pub fn error(error: HandlerError, count: usize, skip: usize) -> ExecuteResult

Create an execute result indicating an abnormal handler error.