pub struct KFuture<T>where
T: Send,{ /* private fields */ }Expand description
A custom future implementation, that can be fulfilled via its paired promise.
Implementations
Sourceimpl<T> KFuture<T>where
T: Send,
impl<T> KFuture<T>where
T: Send,
Sourcepub fn wait(self) -> T
pub fn wait(self) -> T
Wait for the future to be fulfilled and return the value.
This method panics, if there is an error with the link to the promise.
Sourcepub fn wait_timeout(self, timeout: Duration) -> Result<T, WaitErr<KFuture<T>>>
pub fn wait_timeout(self, timeout: Duration) -> Result<T, WaitErr<KFuture<T>>>
Wait for the future to be fulfilled or the timeout to expire.
If the timeout expires, the future itself is returned, so it can be retried later.
Sourceimpl<T, E> KFuture<Result<T, E>>
impl<T, E> KFuture<Result<T, E>>
Sourcepub fn wait_expect(self, timeout: Duration, error_msg: &'static str) -> T
pub fn wait_expect(self, timeout: Duration, error_msg: &'static str) -> T
Wait for the future to be fulfilled or the timeout to expire.
If the result of the future is an error or the the timeout expires, this method will panic with an appropriate error message.