pub struct NamedPath { /* private fields */ }Expand description
A named actor path identifies a service, rather than a concrete actor instance
Named paths must be registered to a particular actor, and their registration can be changed over time, as actors fail and are replaced, for example.
Named paths may be described hierarchically, similar to URLs.
A named path may look something like "tcp://127.0.0.1:8080/my-actor-group/my-actor", for example.
Implementations
Sourceimpl NamedPath
impl NamedPath
Sourcepub fn new(
protocol: Transport,
address: IpAddr,
port: u16,
path: Vec<String>,
) -> NamedPath
pub fn new( protocol: Transport, address: IpAddr, port: u16, path: Vec<String>, ) -> NamedPath
Construct a new named path from parts
Make sure that none of the elements of the path vector contain slashes (i.e., /),
as those will be the path separators for the individual elements later.
Sourcepub fn with_socket(
protocol: Transport,
socket: SocketAddr,
path: Vec<String>,
) -> NamedPath
pub fn with_socket( protocol: Transport, socket: SocketAddr, path: Vec<String>, ) -> NamedPath
Construct a new named path from a socket and vector of path elements
Make sure that none of the elements of the path vector contain slashes (i.e., /),
as those will be the path separators for the individual elements later.
Sourcepub fn with_system(system: SystemPath, path: Vec<String>) -> NamedPath
pub fn with_system(system: SystemPath, path: Vec<String>) -> NamedPath
Construct a new named path from a system path and vector of path elements
Make sure that none of the elements of the path vector contain slashes (i.e., /),
as those will be the path separators for the individual elements later.
Sourcepub fn clone_path(&self) -> Vec<String>
pub fn clone_path(&self) -> Vec<String>
Returns a copy to the path vector
Sourcepub fn system_mut(&mut self) -> &mut SystemPath
pub fn system_mut(&mut self) -> &mut SystemPath
Returns a mutable reference to this path’s system path part