SerError

Struct SerError 

pub struct SerError(/* private fields */);
Errors that can be thrown during serialisation or deserialisation.

Implementations

Source

impl SerError

pub fn kind(&self) -> SerErrorKind

Return the stable category of this serialisation error.

pub fn invalid_data(message: impl Into<String>) -> SerError

Construct an invalid-data serialisation error.

pub fn invalid_type(message: impl Into<String>) -> SerError

Construct an invalid-type serialisation error.

pub fn buffer(message: impl Into<String>) -> SerError

Construct a serialisation buffer error.

pub fn no_buffers_available(message: impl Into<String>) -> SerError

Construct a no-buffers-available serialisation error.

pub fn no_clone() -> SerError

Construct a no-clone serialisation error.

pub fn third_party( context: impl Into<String>, source: impl Error + 'static, ) -> SerError

Construct a third-party serialisation error.

pub fn unknown(message: impl Into<String>) -> SerError

Construct an unknown serialisation error.

pub fn from_debug<E>(error: E) -> SerError
where E: Debug,

Create a serialisation error from any kind of error that implements the Debug trait

This always produces the Unknown kind.