SerialisableValue

Struct SerialisableValue 

pub struct SerialisableValue<T, S>
where T: Send + Debug, S: Serialiser<T>,
{ pub v: T, pub ser: S, }
A data type equivalent to a pair of value and a serialiser for it

Fields

v: T

The value to be serialised

ser: S

The serialise to use

Implementations

Source

impl<T, S> SerialisableValue<T, S>
where T: Send + Debug + 'static, S: Serialiser<T>,

pub fn new(v: T, ser: S) -> SerialisableValue<T, S>

Create a new Serialisable type from a T and a Serialiser for T

pub fn from_tuple(t: (T, S)) -> SerialisableValue<T, S>

Create a new Serialisable type from a pair of T and a Serialiser for T