SessionId

Struct SessionId 

pub struct SessionId(/* private fields */);
Session identifier, part of the NetMessage struct.

Managed by Kompact internally, and may be observed by users to detect session loss.

Implementations

Source

impl SessionId

pub fn new_unique() -> SessionId

Generates a new unique session identifier.

pub fn as_u128(&self) -> u128

Returns the internal representation for serialisation support.

User code should not rely on this representation being stable.

pub fn from_u128(v: u128) -> SessionId

Reconstructs a session identifier from its serialised representation.

User code should not rely on this representation being stable.