pub struct UniquePath { /* private fields */ }Expand description
A unique actor path identifies a concrete instance of an actor
Unique actor paths use the component’s unique id internally.
Unique actor paths become invalid when a component is replaced with a new instance of the same type.
A unique path may look something like "tcp://127.0.0.1:8080#1e555f40-de1d-4aee-8202-64fdc27edfa8", for example.
Implementations
Sourceimpl UniquePath
impl UniquePath
Sourcepub fn new(
protocol: Transport,
address: IpAddr,
port: u16,
id: Uuid,
) -> UniquePath
pub fn new( protocol: Transport, address: IpAddr, port: u16, id: Uuid, ) -> UniquePath
Construct a new unique path from parts
Sourcepub fn with_system(system: SystemPath, id: Uuid) -> UniquePath
pub fn with_system(system: SystemPath, id: Uuid) -> UniquePath
Construct a new unique path from a system path and an id
Sourcepub fn with_socket(
protocol: Transport,
socket: SocketAddr,
id: Uuid,
) -> UniquePath
pub fn with_socket( protocol: Transport, socket: SocketAddr, id: Uuid, ) -> UniquePath
Construct a new unique path with a socket and an id
Sourcepub fn system_mut(&mut self) -> &mut SystemPath
pub fn system_mut(&mut self) -> &mut SystemPath
Returns a mutable reference to this path’s system path part