Dispatcher

Trait Dispatcher 

pub trait Dispatcher: ActorRaw<Message = DispatchEnvelope> {
    // Required method
    fn system_path(&mut self) -> SystemPath;
}
A dispatcher is a system component that knows how to route messages and create system paths

If you need a custom networking implementation, it must implement Dispatcher to allow messages to be routed correctly to channels, for example.

See NetworkDispatcher for the provided networking dispatcher solution.

Required Methods

fn system_path(&mut self) -> SystemPath

Returns the system path for this dispatcher

Implementors