SerialisationId

Trait SerialisationId 

pub trait SerialisationId {
    const SER_ID: u64;
}
A trait that acts like a stable TypeId for serialisation

Requires ids to be assigned manually in some consistent fashion so they can be reliable compared between in different binaries and rust versions.

This trait is used with serialisers that can deal with a large number of types but require some internal differentiation, such as Serde, for example.

Required Associated Constants

const SER_ID: u64

The serialisation id for this type

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors