TimerRefFactory

Trait TimerRefFactory 

pub trait TimerRefFactory {
    // Required method
    fn timer_ref(&self) -> TimerRef<Uuid, ActorRefState, ActorRefState>;

    // Provided method
    fn now(&self) -> Instant { ... }
}
A factory trait to produce instances of TimerRef

Required Methods

fn timer_ref(&self) -> TimerRef<Uuid, ActorRefState, ActorRefState>

Returns the timer reference for associated with this factory

Provided Methods

fn now(&self) -> Instant

Returns the current time according to the underlying timer implementation.

Implementors