Never

Type Alias Never 

pub type Never = !;
A more readable placeholder for a stable Never (!) type.

It is recommended to use this in port directions and actor types, which do not expect any messages, instead of the unit type (). This way the compiler should correctly identify any handlers enforced to be implemented by the API as dead code and eliminate them, resulting in smaller code sizes.