pub type RegistrationResult = Result<ActorPath, RegistrationError>;Expand description
Convenience alias for the result of a path registration attempt
Aliased Type
pub enum RegistrationResult {
Ok(ActorPath),
Err(RegistrationError),
}pub type RegistrationResult = Result<ActorPath, RegistrationError>;Convenience alias for the result of a path registration attempt
pub enum RegistrationResult {
Ok(ActorPath),
Err(RegistrationError),
}