pub struct ComponentCore { /* private fields */ }Expand description
The core of a Kompact component
Contains the unique id, as well as references to the Kompact system, internal state variables, and the component instance itself.
Implementations
Sourceimpl ComponentCore
impl ComponentCore
Sourcepub fn system(&self) -> &KompactSystem
pub fn system(&self) -> &KompactSystem
Returns a reference to the Kompact system this component is a part of
Sourcepub fn component(&self) -> Arc<dyn CoreContainer>
pub fn component(&self) -> Arc<dyn CoreContainer>
Returns the component instance itself, wrapped in an Arc
This method will panic if the component hasn’t been properly initialised, yet!