pub struct ActorStore { /* private fields */ }Expand description
Lookup structure for storing and retrieving DynActorRefs.
UUID-based references are stored in a HashMap, and path-based named references
are stored in a Trie structure.
Notes
The sequence trie supports the use case of grouping many DynActorRef under the same path, similar to a directory structure. Thus, actors can broadcast to all actors under a certain path without requiring explicit identifiers for them.
Ex: Broadcasting a message to actors stored under the system path “tcp://127.0.0.1:8080/pongers/*” Ex: Selecting one of the actors stored under the system path “tcp://127.0.0.1:8080/pongers/?” for delivery
Implementations
Sourceimpl ActorStore
impl ActorStore
Sourcepub fn new() -> ActorStore
pub fn new() -> ActorStore
Return a new, empty instance