pub enum NetworkStatus {
Show 13 variants
ConnectionEstablished(SystemPath, SessionId),
ConnectionLost(SystemPath, SessionId),
ConnectionDropped(SystemPath),
ConnectionClosed(SystemPath, SessionId),
BlockedSystem(SystemPath),
BlockedIp(IpAddr),
BlockedIpNet(IpNet),
AllowedIpNet(IpNet),
AllowedSystem(SystemPath),
AllowedIp(IpAddr),
SoftConnectionLimitExceeded,
HardConnectionLimitReached,
CriticalNetworkFailure,
}Expand description
Information regarding changes to remote connectivity for a distributed system.
Variants
ConnectionEstablished(SystemPath, SessionId)
Indicates that a connection has been established to the remote system.
ConnectionLost(SystemPath, SessionId)
Indicates that a connection has been lost to the remote system.
ConnectionDropped(SystemPath)
Indicates that a connection has been dropped and queued messages were discarded.
ConnectionClosed(SystemPath, SessionId)
Indicates that a connection has been gracefully closed.
BlockedSystem(SystemPath)
Indicates that a system has been blocked.
BlockedIp(IpAddr)
Indicates that an IP address has been blocked.
BlockedIpNet(IpNet)
Indicates that an IP network has been blocked.
AllowedIpNet(IpNet)
Indicates that an IP network has been allowed after previously being blocked.
AllowedSystem(SystemPath)
Indicates that a system has been allowed after previously being blocked.
AllowedIp(IpAddr)
Indicates that an IP address has been allowed after previously being blocked.
SoftConnectionLimitExceeded
Indicates that the soft connection limit has been exceeded.
HardConnectionLimitReached
Indicates that the hard connection limit has been reached.
CriticalNetworkFailure
Indicates that the transport layer encountered a critical failure.