pub struct Recipient<M> { /* private fields */ }Expand description
A version of ActorRef that automatically converts M into some M'
as specified by the actor that created the Recipient from its own ActorRef.
This can be used to expose only a subset of an actor’s interface to another actor.
Note
The indirection provided by this Recipient has some performance impact.
Use benchmarking to establish whether or not the better encapsulation is worth
the performance loss in your scenario.
Implementations