pub struct RecoveryHandler { /* private fields */ }Expand description
Instructions on how to recover from a component fault
The action described by this object will be executed on the Supervisor. This means you cannot block on the result of any notify futures, without deadlocking your system!
If you need to perform a complicated setup sequence, consider starting a temporary component to drive the futures involved, instead of handling everything in the recovery handler.
An instance of this can be produced via FaultContext::recover_with or other convenience methods on FaultContext.