pub struct FieldHashBucketRouting<M, T, H>{ /* private fields */ }Expand description
A router using consistent hashing on some field of the message
Changing the membership is supported, but will result in bucket reassignments.
Implementations
Sourceimpl<M, T, H> FieldHashBucketRouting<M, T, H>
impl<M, T, H> FieldHashBucketRouting<M, T, H>
Sourcepub fn new(
hasher_builder: H,
field_extractor: fn(&M) -> &T,
) -> FieldHashBucketRouting<M, T, H>
pub fn new( hasher_builder: H, field_extractor: fn(&M) -> &T, ) -> FieldHashBucketRouting<M, T, H>
Create a new instance of this router using the provided hasher and field extractor function
Sourcepub fn hash_field(&self, field: &T) -> u64
pub fn hash_field(&self, field: &T) -> u64
Hashes the field using this router’s Hasher
Sourcepub fn hash_message(&self, msg: &M) -> u64
pub fn hash_message(&self, msg: &M) -> u64
Extracts and hashes the msg field using this router’s Hasher
Sourcepub fn get_bucket(&self, msg: &M, length: usize) -> usize
pub fn get_bucket(&self, msg: &M, length: usize) -> usize
Provides the bucket index for the msg for length buckets
It does so by calling hash_message internally and then using modulo arithmentic to decide a bucket from the hash.