pub struct BufferConfig { /* private fields */ }Expand description
The configuration for the network buffers
Implementations
Sourceimpl BufferConfig
impl BufferConfig
Sourcepub fn from_config(config: &Config) -> BufferConfig
pub fn from_config(config: &Config) -> BufferConfig
Tries to deserialise a configuration instance from the specified in the given config.
Returns the same values as BufferConfig::default if it fails to read from the config.
Sourcepub fn from_config_file<P>(path: P) -> BufferConfig
pub fn from_config_file<P>(path: P) -> BufferConfig
Tries to deserialise a BufferConfig from a TOML file at path
Returns the same values as BufferConfig::default if it fails to read from the config.
Panics
Panics if it fails to load the file or fails to load the file as TOML.
Sourcepub fn chunk_size(&mut self, size: usize)
pub fn chunk_size(&mut self, size: usize)
Sets the chunk_size to the given number of bytes.
Specifies the size in bytes of each BufferChunk instance produced by pools using this configuration.
Must be at least 128 bytes, and must also be greater than encode_buf_min_free_space.
Sourcepub fn chunk_size_bytes(&self) -> usize
pub fn chunk_size_bytes(&self) -> usize
Returns the configured chunk size in bytes.
Sourcepub fn initial_chunk_count(&mut self, count: usize)
pub fn initial_chunk_count(&mut self, count: usize)
Sets the initial_chunk_count to the given number.
Specifies the number of BufferChunk instances that pools using this configuration create initially.
May be at most the value of max_chunk_count.
Sourcepub fn max_chunk_count(&mut self, count: usize)
pub fn max_chunk_count(&mut self, count: usize)
Sets the max_chunk_count to the given number.
Specifies the maximum number of BufferChunk instances that pools using this configuration may create.
Must be at least the value of initial_chunk_count.
Sourcepub fn encode_buf_min_free_space(&mut self, size: usize)
pub fn encode_buf_min_free_space(&mut self, size: usize)
Sets the encode_buf_min_free_space to the given number of bytes.
This sets the minimum number of bytes an EncodeBuffer must have available before attempting any serialisation into it.
Must be less than chunk_size.