pub struct SerialisableValue<T, S>{
pub v: T,
pub ser: S,
}Expand description
A data type equivalent to a pair of value and a serialiser for it
Fields
v: TThe value to be serialised
ser: SThe serialise to use
Implementations
Sourceimpl<T, S> SerialisableValue<T, S>
impl<T, S> SerialisableValue<T, S>
Sourcepub fn new(v: T, ser: S) -> SerialisableValue<T, S>
pub fn new(v: T, ser: S) -> SerialisableValue<T, S>
Create a new Serialisable type from a T and a Serialiser for T
Sourcepub fn from_tuple(t: (T, S)) -> SerialisableValue<T, S>
pub fn from_tuple(t: (T, S)) -> SerialisableValue<T, S>
Create a new Serialisable type from a pair of T and a Serialiser for T