pub trait BlockingFutureExt: Sized + Future {
// Provided methods
fn wait(self) -> Self::Output { ... }
fn wait_timeout(
self,
timeout: Duration,
) -> Result<Self::Output, WaitErr<Self>>
where Self: Unpin { ... }
}Expand description
Extension methods for blocking on futures from synchronous code.
Async callers should .await futures directly. These methods are intended for
callers that deliberately want to bridge back into a synchronous context.
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.