DynActorRefFactory

Trait DynActorRefFactory 

pub trait DynActorRefFactory {
    // Required method
    fn dyn_ref(&self) -> DynActorRef;
}
A trait for things that can deal with network messages

Required Methods

fn dyn_ref(&self) -> DynActorRef

Returns a version of an actor ref that can only be used for network messages, but not for typed messages.

Implementations on Foreign Types

Source

impl<CD> DynActorRefFactory for Arc<Component<CD>>
where CD: ComponentTraits,

Available on crate feature distributed only.

Implementors

Source

impl<M> DynActorRefFactory for ActorRef<M>
where M: MessageBounds,

Available on crate feature distributed only.
Source

impl<M> DynActorRefFactory for ActorRefStrong<M>
where M: MessageBounds,

Available on crate feature distributed only.