pub trait Provide<P>where
P: Port + 'static,{
// Required method
fn handle(
&mut self,
event: <P as Port>::Request,
) -> Result<Handled, HandlerError>;
}Expand description
A trait implementing handling of provided events of P
This is equivalent to a Kompics Handler subscribed on a provided port of type P.