pub trait Serialisable: Send + Debug {
// Required methods
fn ser_id(&self) -> u64;
fn size_hint(&self) -> Option<usize>;
fn serialise(&self, buf: &mut dyn BufMut) -> Result<(), SerError>;
fn local(
self: Box<Self>,
) -> Result<Box<dyn Any + Send>, Box<dyn Serialisable>>;
// Provided methods
fn serialised(&self) -> Result<Serialised, SerError> { ... }
fn cloned(&self) -> Option<Box<dyn Serialisable>> { ... }
}Expand description
A trait for values that can serialise themselves into a buffer
Required Methods
Sourcefn ser_id(&self) -> u64
fn ser_id(&self) -> u64
The serialisation id for this serialisable
Serialisation ids are used to determine the deserialiser to use with a particular byte buffer. They are prepended to the actual serialised data and read first during deserialisation. Serialisation ids must be globally unique within a distributed Kompact system.
Sourcefn size_hint(&self) -> Option<usize>
fn size_hint(&self) -> Option<usize>
An indicator how many bytes must be reserved in a buffer for a value to be serialsed into it with this serialiser
If the total size is unknown, None should be returned.
Generally, size hints should be cheap to calculate, compared to the actual serialisation, since they are simply optimisations to avoid many small memory allocations during the serialisation process.
Provided Methods
Sourcefn serialised(&self) -> Result<Serialised, SerError>
fn serialised(&self) -> Result<Serialised, SerError>
Serialise with a one-off buffer
Calls serialise internally by default.
Sourcefn cloned(&self) -> Option<Box<dyn Serialisable>>
fn cloned(&self) -> Option<Box<dyn Serialisable>>
Try to produce a cheap in-memory copy of this
The default implementation returns None.